@@ -11,6 +11,7 @@ import re
 import cgi
 import ast
 import json
+import random
 from types import GeneratorType
 from jinja2.exceptions import TemplateNotFound
 from etgen.html import E, tostring
@@ -640,9 +641,10 @@ class Index(View):
             )
             context.update(ar=ar)
 
+            no_cache = ""
             if 'update_found' in request.GET:
-                context.update(lv=f"?lv={int(settings.SITE.kernel.code_mtime)}")
-
+                no_cache = "?mtime={}".format(random.randint(111111, 999999))
+            context.update(no_cache=no_cache)
             context = ar.get_printable_context(**context)
             env = settings.SITE.plugins.jinja.renderer.jinja_env
             template = env.get_template("react/main.html")
